<a id="mypy-boto3-memorydb"></a>

# mypy-boto3-memorydb

[![PyPI - mypy-boto3-memorydb](https://img.shields.io/pypi/v/mypy-boto3-memorydb.svg?color=blue)](https://pypi.org/project/mypy-boto3-memorydb)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-memorydb.svg?color=blue)](https://pypi.org/project/mypy-boto3-memorydb)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-memorydb?color=blue)](https://pypistats.org/packages/mypy-boto3-memorydb)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.MemoryDB 1.19.1](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/memorydb.html#MemoryDB)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.0.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-memorydb docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-memorydb](#mypy-boto3-memorydb)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `MemoryDB` service.

```bash
python -m pip install boto3-stubs[memorydb]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[memorydb]` in your environment:
  `python -m pip install 'boto3-stubs[memorydb]'`

Both type checking and auto-complete should work for `MemoryDB` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[memorydb]` in your environment:
  `python -m pip install 'boto3-stubs[memorydb]'`

Both type checking and auto-complete should work for `MemoryDB` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[memorydb]` in your environment:
  `python -m pip install 'boto3-stubs[memorydb]'`
- Run `mypy` as usual

Type checking should work for `MemoryDB` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[memorydb]` in your environment:
  `python -m pip install 'boto3-stubs[memorydb]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `MemoryDB` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`MemoryDBClient` provides annotations for `boto3.client("memorydb")`.

```python
import boto3

from mypy_boto3_memorydb import MemoryDBClient

client: MemoryDBClient = boto3.client("memorydb")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: MemoryDBClient = session.client("memorydb")
```

<a id="literals"></a>

### Literals

`mypy_boto3_memorydb.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_memorydb.literals import (
    AZStatusType,
    AuthenticationTypeType,
    InputAuthenticationTypeType,
    ServiceUpdateStatusType,
    ServiceUpdateTypeType,
    SourceTypeType,
    ServiceName,
)

def check_value(value: AZStatusType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_memorydb.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_memorydb.type_defs import (
    ACLPendingChangesTypeDef,
    ACLTypeDef,
    ACLsUpdateStatusTypeDef,
    AuthenticationModeTypeDef,
    AuthenticationTypeDef,
    AvailabilityZoneTypeDef,
    BatchUpdateClusterRequestRequestTypeDef,
    BatchUpdateClusterResponseTypeDef,
    ClusterConfigurationTypeDef,
    ClusterPendingUpdatesTypeDef,
    ClusterTypeDef,
    CopySnapshotRequestRequestTypeDef,
    CopySnapshotResponseTypeDef,
    CreateACLRequestRequestTypeDef,
    CreateACLResponseTypeDef,
    CreateClusterRequestRequestTypeDef,
    CreateClusterResponseTypeDef,
    CreateParameterGroupRequestRequestTypeDef,
    CreateParameterGroupResponseTypeDef,
    CreateSnapshotRequestRequestTypeDef,
    CreateSnapshotResponseTypeDef,
    CreateSubnetGroupRequestRequestTypeDef,
    CreateSubnetGroupResponseTypeDef,
    CreateUserRequestRequestTypeDef,
    CreateUserResponseTypeDef,
    DeleteACLRequestRequestTypeDef,
    DeleteACLResponseTypeDef,
    DeleteClusterRequestRequestTypeDef,
    DeleteClusterResponseTypeDef,
    DeleteParameterGroupRequestRequestTypeDef,
    DeleteParameterGroupResponseTypeDef,
    DeleteSnapshotRequestRequestTypeDef,
    DeleteSnapshotResponseTypeDef,
    DeleteSubnetGroupRequestRequestTypeDef,
    DeleteSubnetGroupResponseTypeDef,
    DeleteUserRequestRequestTypeDef,
    DeleteUserResponseTypeDef,
    DescribeACLsRequestRequestTypeDef,
    DescribeACLsResponseTypeDef,
    DescribeClustersRequestRequestTypeDef,
    DescribeClustersResponseTypeDef,
    DescribeEngineVersionsRequestRequestTypeDef,
    DescribeEngineVersionsResponseTypeDef,
    DescribeEventsRequestRequestTypeDef,
    DescribeEventsResponseTypeDef,
    DescribeParameterGroupsRequestRequestTypeDef,
    DescribeParameterGroupsResponseTypeDef,
    DescribeParametersRequestRequestTypeDef,
    DescribeParametersResponseTypeDef,
    DescribeServiceUpdatesRequestRequestTypeDef,
    DescribeServiceUpdatesResponseTypeDef,
    DescribeSnapshotsRequestRequestTypeDef,
    DescribeSnapshotsResponseTypeDef,
    DescribeSubnetGroupsRequestRequestTypeDef,
    DescribeSubnetGroupsResponseTypeDef,
    DescribeUsersRequestRequestTypeDef,
    DescribeUsersResponseTypeDef,
    EndpointTypeDef,
    EngineVersionInfoTypeDef,
    EventTypeDef,
    FailoverShardRequestRequestTypeDef,
    FailoverShardResponseTypeDef,
    FilterTypeDef,
    ListAllowedNodeTypeUpdatesRequestRequestTypeDef,
    ListAllowedNodeTypeUpdatesResponseTypeDef,
    ListTagsRequestRequestTypeDef,
    ListTagsResponseTypeDef,
    NodeTypeDef,
    ParameterGroupTypeDef,
    ParameterNameValueTypeDef,
    ParameterTypeDef,
    PendingModifiedServiceUpdateTypeDef,
    ReplicaConfigurationRequestTypeDef,
    ResetParameterGroupRequestRequestTypeDef,
    ResetParameterGroupResponseTypeDef,
    ReshardingStatusTypeDef,
    ResponseMetadataTypeDef,
    SecurityGroupMembershipTypeDef,
    ServiceUpdateRequestTypeDef,
    ServiceUpdateTypeDef,
    ShardConfigurationRequestTypeDef,
    ShardConfigurationTypeDef,
    ShardDetailTypeDef,
    ShardTypeDef,
    SlotMigrationTypeDef,
    SnapshotTypeDef,
    SubnetGroupTypeDef,
    SubnetTypeDef,
    TagResourceRequestRequestTypeDef,
    TagResourceResponseTypeDef,
    TagTypeDef,
    UnprocessedClusterTypeDef,
    UntagResourceRequestRequestTypeDef,
    UntagResourceResponseTypeDef,
    UpdateACLRequestRequestTypeDef,
    UpdateACLResponseTypeDef,
    UpdateClusterRequestRequestTypeDef,
    UpdateClusterResponseTypeDef,
    UpdateParameterGroupRequestRequestTypeDef,
    UpdateParameterGroupResponseTypeDef,
    UpdateSubnetGroupRequestRequestTypeDef,
    UpdateSubnetGroupResponseTypeDef,
    UpdateUserRequestRequestTypeDef,
    UpdateUserResponseTypeDef,
    UserTypeDef,
)

def get_structure() -> ACLPendingChangesTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-memorydb` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-memorydb docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
